## Citing Academy

If you use Academy in your work, please cite our preprint: [**Empowering Scientific Workflows with Federated Agents**](https://arxiv.org/abs/2505.05428).

> Pauloski, J. Gregory, Yadu Babuji, Ryan Chard, Mansi Sakarvadia, Kyle Chard, and Ian Foster. "Empowering Scientific Workflows with Federated Agents." arXiv preprint arXiv:2505.05428 (2025).

```bib
@misc{pauloski2025academy,
    title = {Empowering {S}cientific {W}orkflows with {F}ederated {A}gents},
    author = {J. Gregory Pauloski and Yadu Babuji and Ryan Chard and Mansi Sakarvadia and Kyle Chard and Ian Foster},
    archiveprefix = {arXiv},
    eprint = {2505.05428},
    primaryclass = {cs.MA},
    url = {https://arxiv.org/abs/2505.05428},
    year = {2025}
}
```

## Featured Publications

*If you use Academy in your work and would like to be featured on this page, [open an issue](https://github.com/academy-agents/academy/issues){target=_blank} or [propose a pull request](https://github.com/academy-agents/academy/pulls){target=_blank} on GitHub.*

<!-- Use IEEE format here (bibtex to IEEE: https://bibtex.online/) -->

* J.G. Pauloski, K. Chard, I. Foster. "[Agentic Discovery: Closing the Loop With Cooperative Agents](https://doi.ieeecomputersociety.org/10.1109/MC.2025.3575029){target=_blank}," in Computer, vol. 58, no. 10, pp. 20-27, 2025.
